import { csvParse, select } from 'd3';
import topojson from 'topojson-client';
import { map } from './map';

const worldAtlasURL =
  'https://gist.githubusercontent.com/eddyw/bd31bfb563c2356d32d69efe363fc07b/raw/cf9245ca33b54f32f64ad600986acd40f5f6799d/eddyw-world-110m.json';

export const viz = (
  container,
  { state, setState }
) => {
  const width = window.innerWidth;
  const height = window.innerHeight;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  // state.data could be:
  // * undefined
  // * 'LOADING'
  // * An array of objects
  const { data } = state;

  if (data && data !== 'LOADING') {
    svg.call(map, {
      data
    });
  }

  if (data === undefined) {
    setState((state) => ({
      ...state,
      data: 'LOADING',
    }));
    fetch(worldAtlasURL)
      .then((response) => response.json())
      .then((topoJSONData) => {
        const data = topojson.feature(
          topoJSONData,
          'countries'
        );
        setState((state) => ({
          ...state,
          data,
        }));
      });
  }
};
